You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openmeetings.apache.org by so...@apache.org on 2017/12/09 06:12:46 UTC

openmeetings git commit: [OPENMEETINGS-1777] some javadoc errors are fixed

Repository: openmeetings
Updated Branches:
  refs/heads/4.0.x 13834f80a -> 575d42b25


[OPENMEETINGS-1777] some javadoc errors are fixed


Project: http://git-wip-us.apache.org/repos/asf/openmeetings/repo
Commit: http://git-wip-us.apache.org/repos/asf/openmeetings/commit/575d42b2
Tree: http://git-wip-us.apache.org/repos/asf/openmeetings/tree/575d42b2
Diff: http://git-wip-us.apache.org/repos/asf/openmeetings/diff/575d42b2

Branch: refs/heads/4.0.x
Commit: 575d42b258c86c3a3197da2eb01763dc41689d92
Parents: 13834f8
Author: Maxim Solodovnik <so...@gmail.com>
Authored: Sat Dec 9 13:11:04 2017 +0700
Committer: Maxim Solodovnik <so...@gmail.com>
Committed: Sat Dec 9 13:11:04 2017 +0700

----------------------------------------------------------------------
 .../core/remote/ScopeApplicationAdapter.java    |  33 +++---
 .../calendar/caldav/AppointmentManager.java     |  32 +++++-
 .../service/calendar/caldav/IcalUtils.java      |  10 +-
 .../caldav/handler/CalendarHandler.java         |  10 +-
 .../calendar/caldav/handler/EtagsHandler.java   |   8 +-
 .../calendar/caldav/methods/SyncMethod.java     |   4 +-
 .../calendar/caldav/methods/SyncReportInfo.java |  18 ++--
 .../openmeetings/service/mail/EmailManager.java |  11 +-
 .../service/room/InvitationManager.java         |  15 +--
 .../openmeetings/service/user/UserManager.java  | 106 +++++++++----------
 10 files changed, 140 insertions(+), 107 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-core/src/main/java/org/apache/openmeetings/core/remote/ScopeApplicationAdapter.java
----------------------------------------------------------------------
diff --git a/openmeetings-core/src/main/java/org/apache/openmeetings/core/remote/ScopeApplicationAdapter.java b/openmeetings-core/src/main/java/org/apache/openmeetings/core/remote/ScopeApplicationAdapter.java
index afc8148..27f9e4b 100644
--- a/openmeetings-core/src/main/java/org/apache/openmeetings/core/remote/ScopeApplicationAdapter.java
+++ b/openmeetings-core/src/main/java/org/apache/openmeetings/core/remote/ScopeApplicationAdapter.java
@@ -293,7 +293,7 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 
 	/**
 	 *
-	 * @param map
+	 * @param map - {@link Map} with all statuses
 	 * @return returns key,value Map with multiple return values or null in case of exception
 	 *
 	 */
@@ -425,12 +425,12 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 	 * This function is kind of private/protected as the client won't be able
 	 * to call it with proper values.
 	 *
-	 * @param client
-	 * @param scope
+	 * @param client - client who leave
+	 * @param scope - scope being leaved
 	 */
 	public void roomLeaveByScope(StreamClient client, IScope scope) {
 		try {
-			_log.debug("[roomLeaveByScope] currentClient " + client);
+			_log.debug("[roomLeaveByScope] currentClient {}", client);
 			if (Client.Type.sharing == client.getType() && client.isSharingStarted()) {
 				sendSharingStoped(client);
 			}
@@ -656,7 +656,8 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 
 	/**
 	 * wrapper method
-	 * @param newMessage
+	 *
+	 * @param newMessage - message being sent
 	 */
 	public void sendMessageToMembers(List<?> newMessage) {
 		//Sync to all users of current scope
@@ -792,7 +793,8 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 
 	/**
 	 * wrapper method
-	 * @param newMessage
+	 *
+	 * @param newMessage - message being sent
 	 * @return 1 in case of success, -1 otherwise
 	 */
 	public int sendMessageWithClient(Object newMessage) {
@@ -808,8 +810,9 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 
 	/**
 	 * wrapper method
-	 * @param newMessage
-	 * @param sync
+	 *
+	 * @param newMessage - message being sent
+	 * @param sync - send self
 	 * @return 1 in case of success, -1 otherwise
 	 */
 	public int sendMessageWithClientWithSyncObject(Object newMessage, boolean sync) {
@@ -835,9 +838,9 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 	 * Function is used to send the kick Trigger at the moment,
 	 * it sends a general message to a specific clientId
 	 *
-	 * @param newMessage
-	 * @param uid
-	 * @param scope
+	 * @param newMessage - message being sent
+	 * @param uid - uid of the receiver
+	 * @param scope - scope of message
 	 * @return 1 in case of success, -1 otherwise
 	 */
 	public int sendMessageById(Object newMessage, final String uid, IScope scope) {
@@ -858,8 +861,8 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 	/**
 	 * Sends a message to a user in the same room by its clientId
 	 *
-	 * @param uid
-	 * @param newMessage
+	 * @param uid - uid of the recepient
+	 * @param newMessage - message being sent
 	 * @return 1 in case of no exceptions, -1 otherwise
 	 */
 	public int sendMessageToClient(final String uid, Object newMessage) {
@@ -900,7 +903,7 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 	/**
 	 * Starts recording in interview room
 	 *
-	 * @return - false if there were existing recording, true if recording was started successfully, null if any exception happens
+	 * @param c - client who initiated recording
 	 */
 	public void startInterviewRecording(Client c) {
 		_log.debug("-----------  startInterviewRecording");
@@ -915,7 +918,7 @@ public class ScopeApplicationAdapter extends MultiThreadedApplicationAdapter imp
 	/**
 	 * Stop the recording of the streams and send event to connected users of scope
 	 *
-	 * @return true if interview was found
+	 * @param c - client who stopped recording
 	 */
 	public void stopInterviewRecording(org.apache.openmeetings.db.entity.basic.IClient c) {
 		_log.debug("-----------  stopInterviewRecording");

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/AppointmentManager.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/AppointmentManager.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/AppointmentManager.java
index 399641e..a47b435 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/AppointmentManager.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/AppointmentManager.java
@@ -177,7 +177,9 @@ public class AppointmentManager {
 	/**
 	 * Create or Update calendar on the database.
 	 *
-	 * @param calendar Calendar to update or create
+	 * @param client - {@link HttpClient} to discover calendar
+	 * @param calendar - calendar to be created
+	 * @return <code>true</code> if calendar was created/updated
 	 */
 	public boolean createCalendar(HttpClient client, OmCalendar calendar) {
 		if (calendar.getId() == null && calendar.getSyncType() != SyncType.GOOGLE_CALENDAR) {
@@ -201,14 +203,22 @@ public class AppointmentManager {
 	}
 
 	/**
-	 * @see OmCalendarDao#getByUser(Long)
+	 * Method to get user's calendars
+	 * please see {@link OmCalendarDao#getByUser(Long)}
+	 *
+	 * @param userid - id of the user
+	 * @return the list of the calendars
 	 */
 	public List<OmCalendar> getCalendars(Long userid) {
 		return calendarDao.getByUser(userid);
 	}
 
 	/**
-	 * @see OmCalendarDao#getGoogleCalendars(Long)
+	 * Method to get user's google calendars
+	 * please see {@link OmCalendarDao#getGoogleCalendars(Long)}
+	 *
+	 * @param userId - id of the user
+	 * @return the list of the calendars
 	 */
 	public List<OmCalendar> getGoogleCalendars(Long userId) {
 		return calendarDao.getGoogleCalendars(userId);
@@ -217,6 +227,7 @@ public class AppointmentManager {
 	/**
 	 * Function which when called performs syncing based on the type of Syncing detected.
 	 *
+	 * @param client - {@link HttpClient} to discover calendar
 	 * @param calendar Calendar who's sync has to take place
 	 */
 	public void syncItem(HttpClient client, OmCalendar calendar) {
@@ -246,6 +257,9 @@ public class AppointmentManager {
 
 	/**
 	 * Syncs all the calendars currrently present on the DB.
+	 *
+	 * @param client - {@link HttpClient} to discover calendar
+	 * @param userId - id of the user
 	 */
 	public void syncItems(HttpClient client, Long userId) {
 		List<OmCalendar> calendars = getCalendars(userId);
@@ -256,6 +270,10 @@ public class AppointmentManager {
 
 	/**
 	 * Function which finds all the calendars of the Principal URL of the calendar
+	 *
+	 * @param client - {@link HttpClient} to discover calendar
+	 * @param calendar - calendar to get principal URL from
+	 * @return - <code>true</code> in case calendar was discovered successfully
 	 */
 	private boolean discoverCalendars(HttpClient client, OmCalendar calendar) {
 		cleanupIdleConnections();
@@ -439,6 +457,10 @@ public class AppointmentManager {
 
 	/**
 	 * Function to initialize the Calendar on the type of syncing and whether it can be used or not.
+	 *
+	 * @param client - {@link HttpClient} to discover calendar
+	 * @param calendar - calendar to be inited
+	 * @return <code>true</code> in case calendar was inited
 	 */
 	private boolean initCalendar(HttpClient client, OmCalendar calendar) {
 
@@ -505,7 +527,9 @@ public class AppointmentManager {
 	 * Function for create/updating multiple appointment on the server.
 	 * Performs modification alongside of creation new events on the server.
 	 *
+	 * @param client - {@link HttpClient} to discover calendar
 	 * @param appointment Appointment to create/update.
+	 * @return <code>true</code> in case item was updated
 	 */
 	public boolean updateItem(HttpClient client, Appointment appointment) {
 		cleanupIdleConnections();
@@ -535,7 +559,9 @@ public class AppointmentManager {
 	 * Delete's on the Server only if the ETag of the Appointment is the one on the server,
 	 * i.e. only if the Event hasn't changed on the Server.
 	 *
+	 * @param client - {@link HttpClient} to discover calendar
 	 * @param appointment Appointment to Delete
+	 * @return <code>true</code> in case item was deleted
 	 */
 	public boolean deleteItem(HttpClient client, Appointment appointment) {
 		cleanupIdleConnections();

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/IcalUtils.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/IcalUtils.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/IcalUtils.java
index 827911a..082a873 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/IcalUtils.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/IcalUtils.java
@@ -324,7 +324,7 @@ public class IcalUtils {
 	 *
 	 * @param str      Date representation in String.
 	 * @param patterns Patterns to parse the date against
-	 * @param timeZone Timezone of the Date.
+	 * @param _timeZone Timezone of the Date.
 	 * @return <code>java.util.Date</code> representation of string or
 	 * <code>null</code> if the Date could not be parsed.
 	 */
@@ -367,9 +367,9 @@ public class IcalUtils {
 	 *
 	 * @param appointment to be converted to iCalendar
 	 * @return iCalendar representation of the Appointment
-	 * @throws Exception
+	 * @throws NoSuchElementException - in case time zone was not found
 	 */
-	public Calendar parseAppointmenttoCalendar(Appointment appointment) throws Exception {
+	public Calendar parseAppointmenttoCalendar(Appointment appointment) throws NoSuchElementException {
 		String tzid = parseTimeZone(null, appointment.getOwner()).getID();
 
 		TimeZoneRegistry registry = TimeZoneRegistryFactory.getInstance().createRegistry();
@@ -452,9 +452,9 @@ public class IcalUtils {
 	 * @param appointments List of Appointments for the Calendar
 	 * @param ownerId      Owner of the Appointments
 	 * @return VCALENDAR representation of the Appointments
-	 * @throws Exception
+	 * @throws NoSuchElementException in case time zone was not found
 	 */
-	public Calendar parseAppointmentstoCalendar(List<Appointment> appointments, Long ownerId) throws Exception {
+	public Calendar parseAppointmentstoCalendar(List<Appointment> appointments, Long ownerId) throws NoSuchElementException {
 		String tzid = parseTimeZone(null, userDao.get(ownerId)).getID();
 
 		TimeZoneRegistry registry = TimeZoneRegistryFactory.getInstance().createRegistry();

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/CalendarHandler.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/CalendarHandler.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/CalendarHandler.java
index 87500e6..341c449 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/CalendarHandler.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/CalendarHandler.java
@@ -29,10 +29,12 @@ import org.apache.openmeetings.db.entity.calendar.OmCalendar;
  * This is a helper class to help Syncing of CalDAV calendars.
  * <p>
  * There are currently three types of Sync Handlers. Namely:
- * <li>ETAGs Sync</li>
- * <li>CTAGs Sync (Similar to ETAGs but an additional step is necessary)</li>
- * <li>WebDAV-Sync Report</li>
- * <li>Calendar-Multiget Report</li>
+ * <ul>
+ *   <li>ETAGs Sync</li>
+ *   <li>CTAGs Sync (Similar to ETAGs but an additional step is necessary)</li>
+ *   <li>WebDAV-Sync Report</li>
+ *   <li>Calendar-Multiget Report</li>
+ * </ul>
  */
 public interface CalendarHandler {
 

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/EtagsHandler.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/EtagsHandler.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/EtagsHandler.java
index a037220..8142551 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/EtagsHandler.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/handler/EtagsHandler.java
@@ -65,9 +65,11 @@ import net.fortuna.ical4j.model.Component;
  * Then, for each href and etag, we get, something like key-value pair.
  * <p>
  * We then check for three things:
- * <li>Addition of a new event.</li>
- * <li>Modification of an existing event.</li>
- * <li>Deletion of events which are not in the response.</li>
+ * <ul>
+ *   <li>Addition of a new event.</li>
+ *   <li>Modification of an existing event.</li>
+ *   <li>Deletion of events which are not in the response.</li>
+ * </ul>
  */
 public class EtagsHandler extends AbstractCalendarHandler {
 	private static final Logger log = Red5LoggerFactory.getLogger(EtagsHandler.class, getWebAppRootKey());

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncMethod.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncMethod.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncMethod.java
index f4d11cd..43e1241 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncMethod.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncMethod.java
@@ -105,8 +105,8 @@ public class SyncMethod extends DavMethodBase {
 	 * Adapted from DavMethodBase to handle MultiStatus responses.
 	 *
 	 * @return MultiStatus response
-	 * @throws IOException
-	 * @throws DavException
+	 * @throws IOException if the response body could not be parsed
+	 * @throws DavException in case of error
 	 */
 	@Override
 	public MultiStatus getResponseBodyAsMultiStatus() throws IOException, DavException {

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncReportInfo.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncReportInfo.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncReportInfo.java
index c1242f6..1a45dbe 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncReportInfo.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/calendar/caldav/methods/SyncReportInfo.java
@@ -29,15 +29,17 @@ import org.w3c.dom.Element;
 
 /**
  * Used to represent a Sync Report, defined in RFC 6578. Taken from RFC 6578 are
- * the following XML definitions <br/>
- * <br/>
+ * the following XML definitions
+ *
  * <code>
  * &lt;!ELEMENT sync-collection (sync-token, sync-level, limit?, prop)&gt;
- * <br/><br/>
- * &lt;!ELEMENT sync-token #PCDATA&gt; <br/>
+ *
+ *
+ * &lt;!ELEMENT sync-token #PCDATA&gt;
  * &lt;!-- Text MUST be a valid URI --&gt;
- * <br/><br/>
- * &lt;!ELEMENT sync-level CDATA&gt; <br/>
+ *
+ *
+ * &lt;!ELEMENT sync-level CDATA&gt;
  * &lt;!-- Text MUST be either "1" or "infinite" --&gt;
  * </code>
  *
@@ -135,8 +137,8 @@ public class SyncReportInfo implements XmlSerializable {
 
 	/**
 	 * @see XmlSerializable#toXml(Document)
-	 * @param document
-	 * @return
+	 * @param document - document to create report info from
+	 * @return report info as {@link Element}
 	 */
 	@Override
 	public Element toXml(Document document) {

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/mail/EmailManager.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/mail/EmailManager.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/mail/EmailManager.java
index af9b1cb..d16b5c6 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/mail/EmailManager.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/mail/EmailManager.java
@@ -59,12 +59,11 @@ public class EmailManager {
 	/**
 	 * sends a mail address to the user with his account data
 	 *
-	 * @param username
-	 * @param userpass
-	 * @param email
-	 * @param hash
-	 * @return
-	 * @throws Exception
+	 * @param username - login of the registered user
+	 * @param email - email of the registered user
+	 * @param hash - activation hash
+	 * @param sendEmailWithVerficationCode - if email with verification code should be sent
+	 * @param langId - language Id
 	 */
 	public void sendMail(String username, String email, String hash, Boolean sendEmailWithVerficationCode, Long langId) {
 		log.debug("sendMail:: username = {}, email = {}", username, email);

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/room/InvitationManager.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/room/InvitationManager.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/room/InvitationManager.java
index 0ea48f1..30c8d3c 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/room/InvitationManager.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/room/InvitationManager.java
@@ -73,11 +73,11 @@ public class InvitationManager implements IInvitationManager {
 	/**
 	 * @author vasya
 	 *
-	 * @param mm
-	 * @param a
-	 * @param message
-	 * @param subject
-	 * @throws Exception
+	 * @param a - appointment this link is related to
+	 * @param mm - attendee being processed
+	 * @param type - type of the message
+	 * @param ical - should iCal appoinment be attached to message
+	 * @throws Exception in case of error happens during sending
 	 */
 	private void sendInvitionLink(Appointment a, MeetingMember mm, MessageType type, boolean ical) throws Exception	{
 		User owner = a.getOwner();
@@ -147,8 +147,9 @@ public class InvitationManager implements IInvitationManager {
 	/**
 	 * @author vasya
 	 *
-	 * @param member
-	 * @param a
+	 * @param a - appointment this link is related to
+	 * @param member - attendee being processed
+	 * @param type - type of the message
 	 */
 	@Override
 	public void processInvitation(Appointment a, MeetingMember member, MessageType type) {

http://git-wip-us.apache.org/repos/asf/openmeetings/blob/575d42b2/openmeetings-service/src/main/java/org/apache/openmeetings/service/user/UserManager.java
----------------------------------------------------------------------
diff --git a/openmeetings-service/src/main/java/org/apache/openmeetings/service/user/UserManager.java b/openmeetings-service/src/main/java/org/apache/openmeetings/service/user/UserManager.java
index b68d58e..b93bbf7 100644
--- a/openmeetings-service/src/main/java/org/apache/openmeetings/service/user/UserManager.java
+++ b/openmeetings-service/src/main/java/org/apache/openmeetings/service/user/UserManager.java
@@ -97,28 +97,28 @@ public class UserManager implements IUserManager {
 	 * default user_level(1) new users will be automatically added to the
 	 * Group with the id specified in the configuration value default.group.id
 	 *
 	 * @param login
 	 * @param userpass
 	 * @param lastname
 	 * @param firstname
 	 * @param email
 	 * @param age
 	 * @param street
 	 * @param additionalname
 	 * @param fax
 	 * @param zip
 	 * @param stateId
 	 * @param town
 	 * @param languageId
 	 * @param phone
 	 * @param sendSMS
 	 * @param generateSipUserData
 	 * @param jNameTimeZone
 	 * @param sendConfirmation
 	 * @return
 	 */
 	@Override
-	public Object registerUser(String login, String userpass, String lastname,
+	public Object registerUser(String login, String password, String lastname,
 			String firstname, String email, Date age, String street,
 			String additionalname, String fax, String zip, String country,
 			String town, long languageId, String phone, boolean sendSMS,
@@ -136,7 +136,7 @@ public class UserManager implements IUserManager {
 					sendConfirmation = _sendConfirmation.booleanValue();
 				}
 				Object user = registerUserInit(UserDao.getDefaultRights(), login,
-						userpass, lastname, firstname, email, age, street,
+						password, lastname, firstname, email, age, street,
 						additionalname, fax, zip, country, town, languageId,
 						true, Arrays.asList(cfgDao.getLong(CONFIG_DEFAULT_GROUP_ID, null)), phone,
 						sendSMS, sendConfirmation, getTimeZone(jNameTimeZone), false, "", "", false, true, null);
@@ -156,36 +156,35 @@ public class UserManager implements IUserManager {
 	}
 
 	/**
-	 * @param user_level
-	 * @param availible
-	 * @param status
-	 * @param login
-	 * @param password
-	 * @param lastname
-	 * @param firstname
-	 * @param email
-	 * @param age
-	 * @param street
-	 * @param additionalname
-	 * @param fax
-	 * @param zip
-	 * @param stateId
-	 * @param town
-	 * @param languageId
-	 * @param sendWelcomeMessage
-	 * @param groups
-	 * @param phone
-	 * @param sendSMS
-	 * @param sendConfirmation
-	 * @param timezone
-	 * @param forceTimeZoneCheck
-	 * @param userOffers
-	 * @param userSearchs
-	 * @param showContactData
-	 * @param showContactDataToContacts
-	 * @return new user OR error code
-	 * @throws NoSuchAlgorithmException
-	 * @throws Exception
+	 * @param rights - {@link Right} to be assigned to the user
+	 * @param login - user login
+	 * @param password - user password
+	 * @param lastname - user last name
+	 * @param firstname - user first name
+	 * @param email - user email
+	 * @param age - user birthday
+	 * @param street - user address street
+	 * @param additionalname - user additional name
+	 * @param fax - user fax
+	 * @param zip - user zip code
+	 * @param country - user country code
+	 * @param town - user town
+	 * @param languageId - language id
+	 * @param sendWelcomeMessage - should confirmation email be sent
+	 * @param groups - ids of user groups
+	 * @param phone - user phone
+	 * @param sendSMS - should SMS be sent to this user
+	 * @param sendConfirmation - should confirmation be sent
+	 * @param timezone - the name of the time zone
+	 * @param forceTimeZoneCheck - should time zone be verified by user
+	 * @param userOffers - what user offers
+	 * @param userSearchs - what user searches
+	 * @param showContactData - is contact data publicly visible
+	 * @param showContactDataToContacts - is contact data visible to contacts
+	 * @param activatedHash - activation hash
+	 * @return {@link User} of code of error as {@link String}
+	 * @throws NoSuchAlgorithmException in case password hashing algorithm is not found
+	 * @throws OmException in case of any issues with provided data
 	 */
 	@Override
 	public Object registerUserInit(Set<Right> rights, String login, String password, String lastname,
@@ -275,9 +274,8 @@ public class UserManager implements IUserManager {
 	}
 
 	/**
-	 * @param sid
-	 * @param room_id
-	 * @return
+	 * @param roomId - id of the room user should be kicked from
+	 * @return <code>true</code> if there were no errors
 	 */
 	@Override
 	public boolean kickUsersByRoomId(Long roomId) {
@@ -97,28 +97,28 @@ public class UserManager implements IUserManager {
 	 * Group with the id specified in the configuration value default.group.id
 	 *
-	 * @param login
-	 * @param userpass
-	 * @param lastname
-	 * @param firstname
-	 * @param email
-	 * @param age
-	 * @param street
-	 * @param additionalname
-	 * @param fax
-	 * @param zip
-	 * @param stateId
-	 * @param town
-	 * @param languageId
-	 * @param phone
-	 * @param sendSMS
-	 * @param generateSipUserData
-	 * @param jNameTimeZone
-	 * @param sendConfirmation
-	 * @return
+	 * @param login - user login
+	 * @param password - user password
+	 * @param lastname - user last name
+	 * @param firstname - user first name
+	 * @param email - user email
+	 * @param age - user birthday
+	 * @param street - user address street
+	 * @param additionalname - user additional name
+	 * @param fax - user fax
+	 * @param zip - user zip code
+	 * @param country - user country code
+	 * @param town - user town
+	 * @param languageId - language id
+	 * @param phone - user phone
+	 * @param sendSMS - should SMS be sent to this user
+	 * @param generateSipUserData - should SIP data be generated
+	 * @param jNameTimeZone - the name of the time zone
+	 * @param _sendConfirmation - should confirmation be sent
+	 * @return {@link User} of code of error as {@link String}
 	 */
 	@Override